# Pallet Simulator

Pallet Simulator is a Python package that provides functionalities for visualizing pallets inside orders and simulating
their stability.

## Installation

You can install the Pallet Simulator package using pip:

``` 
pip install pallet-sim
```

## Usage

Please refer to the examples folder for detailed examples on how to use the Pallet Simulator. The examples demonstrate
how to visualize pallets within orders and simulate their stability.

## Data Structures

The Pallet Simulator uses a JSON-based data structure to represent orders. An order object contains the following
fields:

``` json
{
    "orderID": "order_id",
    "pallets": [
        {
            "palletNr": "palletNr",
            "palletType": "EURO_PALLET",
            "palletDimension": {
                "x": 800.0,
                "y": 1200.0
            },
            "boxes": [
                {
                    "product_code": "0",
                    "anchor": {
                        "x": 313.0,
                        "y": 606.0,
                        "z": 0.0
                    },
                    "dimension": {
                        "x": 159.0,
                        "y": 298.0,
                        "z": 211.0
                    },
                    "approach": "9"
                }
            ]
        }
    ],
    "articles": {
        "0": {
            "description": "description",
            "weight": 5054.0,
            "shippingGroup": "A"
        }
    }
}
```

In this structure, an order consists of multiple pallets, each identified by a palletNr. Each pallet has a type
(palletType), dimensions (palletDimension), and a list of boxes (boxes). Each box is defined by a product code
(product_code), anchor coordinates (anchor), dimensions (dimension), and an approach value (approach).

The articles field represents the articles or products included in the order. Each article is identified by a numeric
key (e.g., "0") and has a description, weight, and shipping group.

The Pallet Simulator utilizes this order structure to generate visual representations of pallets and perform stability
simulations.

Feel free to modify and adapt this structure based on your specific requirements and use cases.

For more details on how to use the Pallet Simulator, please refer to the documentation and examples provided with the
package.

Example files are located under pallet_data/generic_data.

## License

This project is licensed under the MIT License. See the LICENSE file for details.

The MIT License is a permissive open-source license that allows you to use, modify, and distribute the software for both
commercial and non-commercial purposes. It provides you with the freedom to adapt the codebase to suit your needs while
providing attribution to the original authors.

For more information about the MIT License, please visit opensource.org/licenses/MIT.